MapValidator<T extends Map> class abstract

Abstract class for schema-like map validators composed of Field/IdValidator instances.

Inheritance
Available extensions

Constructors

MapValidator({String? id = '', bool nullable = false})

Properties

fields → List<IdValidator<Result>>
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → String?
finalinherited
isNullable → bool
finalinherited
isOptional → bool
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? nullable, bool? optional}) → IValidator
override
isNotValid(dynamic value) → bool
inherited
isNotValidAsync(dynamic value) → FutureOr<bool>
inherited
isValid(dynamic value) → bool
inherited
isValidAsync(dynamic value) → FutureOr<bool>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
nullable<T>() → IValidator
inherited
optional<T>() → IValidator
inherited
toString() → String
A string representation of this object.
inherited
validate(dynamic value, {bool exists = true}) → Result
inherited
validateAsync(dynamic value, {bool exists = true}) → Future<Result>
inherited
validateOrThrow(dynamic value) → Result
inherited
validator(dynamic value) → FutureOr<Result>
override

Operators

operator &(IValidator other) → IValidator

Available on IValidator, provided by the EskemaEskValidatorOperations extension

Combines two validators with a logical AND, same as using all
operator ==(Object other) → bool
The equality operator.
inherited
operator >(Expectation error) → IValidator

Available on IValidator, provided by the EskemaEskValidatorOperations extension

Returns a new validator that will return the error message if the validation fails
operator |(IValidator other) → IValidator

Available on IValidator, provided by the EskemaEskValidatorOperations extension

Combines two validators with a logical OR, same as using any