ValidatorFailedException class

Thrown when a validation fails and validateOrThrow() is used.

Implemented types

Constructors

ValidatorFailedException(Result result)

Properties

hashCode → int
The hash code for this object.
no setterinherited
message → String
Primary human friendly message.
no setter
result → Result
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
summary → String
Machine friendly summary (single line) for logs.
no setter
timestamp → DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited